@@ -60,15 +60,13 @@ namespace
 namespace
 {
   // default color theme's Colors
-  const PanColors& colors (PanColors::get());
-  const char* def_color_str (colors.def_bg.c_str());
-  const char* def_color_fg_str (colors.def_fg.c_str());
+  PanColors const &colors(PanColors::get());
 }
 
-const Article*
-HeaderPane :: get_article (GtkTreeModel* model, GtkTreeIter* iter)
+Article const *HeaderPane ::get_article(GtkTreeModel *model, GtkTreeIter *iter)
 {
-  const Article * a = dynamic_cast<Row*>(PAN_TREE_STORE(model)->get_row(iter))->article;
+  Article const *a =
+    dynamic_cast<Row *>(PAN_TREE_STORE(model)->get_row(iter))->article;
   g_assert (a != nullptr);
   return a;
 }
@@ -79,30 +77,31 @@ HeaderPane :: get_article (GtkTreeModel* model, GtkTreeIter* iter)
 
 namespace
 {
-  typedef std::set<const Article*> articles_t;
+typedef std::set<Article const *> articles_t;
 
-  enum
-  {
-    ICON_READ,
-    ICON_UNREAD,
+enum
+{
+  ICON_READ,
+  ICON_UNREAD,
 
-    ICON_COMPLETE,
-    ICON_COMPLETE_READ,
+  ICON_COMPLETE,
+  ICON_COMPLETE_READ,
 
-    ICON_INCOMPLETE,
-    ICON_INCOMPLETE_READ,
+  ICON_INCOMPLETE,
+  ICON_INCOMPLETE_READ,
 
-    ICON_CACHED,
-    ICON_QUEUED,
-    ICON_ERROR,
-    ICON_EMPTY,
-    ICON_FLAGGED,
-    ICON_GET_FLAGGED,
-    ICON_QTY
-   };
+  ICON_CACHED,
+  ICON_QUEUED,
+  ICON_ERROR,
+  ICON_EMPTY,
+  ICON_FLAGGED,
+  ICON_GET_FLAGGED,
+  ICON_QTY
+};
 
-  struct Icon {
-    const char * icon_file;
+struct Icon
+{
+    char const *icon_file;
     GdkPixbuf * pixbuf;
   } _icons[ICON_QTY] = {
     { "icon_article_read.png",           nullptr },
@@ -122,12 +121,11 @@ namespace
     { "icon_get_flagged.png",            nullptr }
   };
 
-  int
-  get_article_state (const Data& data, const Article * a)
+  int get_article_state(Data const &data, Article const *a)
   {
     int retval;
-    const bool read (data.is_read (a));
-    const int part_state (a->get_part_state());
+    bool const read(data.is_read(a));
+    int const part_state(a->get_part_state());
 
     if (part_state==Article::COMPLETE && read)
       retval = ICON_COMPLETE_READ;
@@ -145,11 +143,10 @@ namespace
     return retval;
   }
 
-  int
-  get_article_action (const Article       * article,
-                      const ArticleCache  & cache,
-                      const Queue         & queue,
-                      const Quark         & message_id)
+  int get_article_action(Article const *article,
+                         ArticleCache const &cache,
+                         Queue const &queue,
+                         Quark const &message_id)
   {
     int offset (ICON_EMPTY);
 
@@ -198,9 +195,9 @@ HeaderPane :: find_highest_followup_score (GtkTreeModel * model,
   int score (-9999);
   GtkTreeIter child;
   if (gtk_tree_model_iter_children (model, &child, parent)) do {
-    const Article * a (get_article (model, &child));
-    score = std::max (score, a->score);
-    score = std::max (score, find_highest_followup_score (model, &child));
+        Article const *a(get_article(model, &child));
+        score = std::max(score, a->score);
+        score = std::max(score, find_highest_followup_score(model, &child));
   } while (gtk_tree_model_iter_next (model, &child));
   return score;
 }
@@ -224,28 +221,28 @@ HeaderPane :: render_score (GtkTreeViewColumn * ,
   HeaderPane * self (static_cast<HeaderPane*>(user_data));
   GtkTreeView * view (GTK_TREE_VIEW (self->_tree_view));
   GtkTreePath * path (gtk_tree_model_get_path (model, iter));
-  const bool expanded (gtk_tree_view_row_expanded (view, path));
+  bool const expanded(gtk_tree_view_row_expanded(view, path));
   gtk_tree_path_free (path);
   if (!expanded)
     score = std::max (score, self->find_highest_followup_score (model, iter));
 
-  const Prefs& prefs (self->_prefs);
+  Prefs const &prefs(self->_prefs);
   std::string bg, fg;
   if (score >= 9999) {
-    fg = prefs.get_color_str ("score-color-watched-fg", def_color_fg_str);
+    fg = prefs.get_color_str ("score-color-watched-fg", colors.def_fg);
     bg = prefs.get_color_str ("score-color-watched-bg", TANGO_CHAMELEON_LIGHT);
   } else if (score >= 5000) {
-    fg = prefs.get_color_str ("score-color-high-fg", def_color_fg_str);
+    fg = prefs.get_color_str ("score-color-high-fg", colors.def_fg);
     bg = prefs.get_color_str ("score-color-high-bg", TANGO_BUTTER_LIGHT);
   } else if (score >= 1) {
-    fg = prefs.get_color_str ("score-color-medium-fg", def_color_fg_str);
+    fg = prefs.get_color_str ("score-color-medium-fg", colors.def_fg);
     bg = prefs.get_color_str ("score-color-medium-bg", TANGO_SKY_BLUE_LIGHT);
   } else if (score <= -9999) {
     fg = prefs.get_color_str ("score-color-ignored-fg", TANGO_ALUMINUM_4);
-    bg = prefs.get_color_str ("score-color-ignored-bg", def_color_str);
+    bg = prefs.get_color_str ("score-color-ignored-bg", colors.def_bg);
   } else if (score <= -1) {
     fg = prefs.get_color_str ("score-color-low-fg", TANGO_ALUMINUM_2);
-    bg = prefs.get_color_str ("score-color-low-bg", def_color_str);
+    bg = prefs.get_color_str ("score-color-low-bg", colors.def_bg);
   }
   else if (score == 0)
   {
@@ -266,8 +263,8 @@ HeaderPane :: render_author (GtkTreeViewColumn * ,
                             GtkTreeIter       * iter,
                             gpointer            user_data)
 {
-  const HeaderPane * self (static_cast<HeaderPane*>(user_data));
-  const Article * a (self->get_article (model, iter));
+  HeaderPane const *self(static_cast<HeaderPane *>(user_data));
+  Article const *a(self->get_article(model, iter));
 
   g_object_set (renderer, "text", a->author.c_str() ,
                          "background", self->_bg.c_str(),
@@ -283,7 +280,7 @@ HeaderPane :: render_lines (GtkTreeViewColumn * ,
                             gpointer            user_data)
 {
 
-  const HeaderPane * self (static_cast<HeaderPane*>(user_data));
+  HeaderPane const *self(static_cast<HeaderPane *>(user_data));
 
   unsigned long lines(0ul);
   std::stringstream str;
@@ -304,7 +301,7 @@ HeaderPane :: render_bytes (GtkTreeViewColumn * ,
                             GtkTreeIter       * iter,
                             gpointer            userdata)
 {
-  const HeaderPane * self (static_cast<HeaderPane*>(userdata));
+  HeaderPane const *self(static_cast<HeaderPane *>(userdata));
 
   unsigned long bytes (0);
   gtk_tree_model_get (model, iter, COL_BYTES, &bytes, -1);
@@ -322,7 +319,7 @@ HeaderPane :: render_date  (GtkTreeViewColumn * ,
                             GtkTreeIter       * iter,
                             gpointer            userdata)
 {
-  const HeaderPane * self (static_cast<HeaderPane*>(userdata));
+  HeaderPane const *self(static_cast<HeaderPane *>(userdata));
 
   gchar* date (nullptr);
   gtk_tree_model_get (model, iter, COL_DATE_STR, &date, -1);
@@ -1266,20 +1263,21 @@ namespace
     Article const *a(pane->get_first_selected_article());
     if (a) {
       const size_t lines = a->get_line_count();
-      bool const is_smallish = lines <= 5000;
-      bool const is_mediumish = lines <= 20000;
+      bool const is_bigish = lines >= 20000;
       bool const image_subject = has_image_type_in_subject(*a);
       bool const is_pictures_newsgroup =
         pane->get_group().to_view().strstr("pictures") != nullptr;
       // This is not the number of MIME parts
       int const part_count = a->get_found_part_count();
 
-      if (is_smallish || image_subject || part_count < 2)
-        pane->_action_manager.activate_action ("read-selected-article");
-      else if (is_mediumish && is_pictures_newsgroup)
-        pane->_action_manager.activate_action ("read-selected-article");
-      else
-        pane->_action_manager.activate_action ("save-articles");
+      // update body pane with article information
+      pane->_action_manager.activate_action ("read-selected-article");
+
+      if (is_bigish && ! is_pictures_newsgroup && ! image_subject
+          && part_count > 1)
+      {
+        pane->_action_manager.activate_action("save-articles");
+      }
     }
     return false;
   }
@@ -1707,7 +1705,8 @@ HeaderPane :: build_tree_columns ()
         nullptr));
       col = gtk_tree_view_column_new ();
       gtk_tree_view_column_set_sizing (col, GTK_TREE_VIEW_COLUMN_FIXED);
-      gtk_tree_view_column_set_fixed_width (col, _prefs.get_int (width_key, 24));
+      // used a fixed width since the column is not resizable
+      gtk_tree_view_column_set_fixed_width (col, 24);
       gtk_tree_view_column_set_resizable (col, false);
       gtk_tree_view_column_pack_start (col, r, false);
       gtk_tree_view_column_set_cell_data_func (col, r, render_state, nullptr, nullptr);
@@ -1722,7 +1721,8 @@ HeaderPane :: build_tree_columns ()
         nullptr));
       col = gtk_tree_view_column_new ();
       gtk_tree_view_column_set_sizing (col, GTK_TREE_VIEW_COLUMN_FIXED);
-      gtk_tree_view_column_set_fixed_width (col, _prefs.get_int (width_key, 24));
+      // used a fixed width since the column is not resizable
+      gtk_tree_view_column_set_fixed_width (col, 24);
       gtk_tree_view_column_set_resizable (col, false);
       gtk_tree_view_column_pack_start (col, r, false);
       gtk_tree_view_column_set_cell_data_func (col, r, render_action, nullptr, nullptr);
@@ -1980,12 +1980,14 @@ HeaderPane :: HeaderPane (ActionManager       & action_manager,
   _tree_view (nullptr),
   _tree_store (nullptr),
   _selection_changed_idle_tag (0),
-  _fg(prefs.get_color_str_wo_fallback ("text-color-fg")),
-  _bg(prefs.get_color_str_wo_fallback ("text-color-bg")),
+  _fg(),
+  _bg(),
   _cache (cache),
   _gui (gui),
   _cleared (true)
 {
+  _fg = prefs.get_color_str ("text-color-fg",colors.def_fg.c_str());
+  _bg = prefs.get_color_str ("text-color-bg", colors.def_bg.c_str());
 
   // init the icons
   for (guint i=0; i<ICON_QTY; ++i)
@@ -2481,8 +2483,8 @@ HeaderPane :: on_prefs_color_changed  (const StringView& key, const GdkRGBA&)
 {
   if (key == "text-color-fg" || key == "text-color-bg")
   {
-    _fg = _prefs.get_color_str ("text-color-fg", def_color_fg_str).c_str();
-    _bg = _prefs.get_color_str ("text-color-bg", def_color_str).c_str();
+    _fg = _prefs.get_color_str ("text-color-fg", colors.def_fg).c_str();
+    _bg = _prefs.get_color_str ("text-color-bg", colors.def_bg).c_str();
     refresh_font();
     build_tree_columns();
   }
